@@ -1,7 +1,7 @@
 /*
  * dfu-programmer
  *
- * $Id: dfu.c 159 2013-05-10 14:13:14Z slarge $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -70,6 +70,7 @@
 
 static uint16_t transaction = 0;
 
+// ________  P R O T O T Y P E S  _______________________________
 #ifdef HAVE_LIBUSB_1_0
 static int32_t dfu_find_interface( struct libusb_device *device,
                                    const dfu_bool honor_interfaceclass,
@@ -78,7 +79,22 @@ static int32_t dfu_find_interface( struct libusb_device *device,
 static int32_t dfu_find_interface( const struct usb_device *device,
                                    const dfu_bool honor_interfaceclass );
 #endif
+/*  Used to find the dfu interface for a device if there is one.
+ *
+ *  device - the device to search
+ *  honor_interfaceclass - if the actual interface class information
+ *                         should be checked, or ignored (bug in device DFU code)
+ *
+ *  returns the interface number if found, < 0 otherwise
+ */
+
 static int32_t dfu_make_idle( dfu_device_t *device, const dfu_bool initial_abort );
+/*  Gets the device into the dfuIDLE state if possible.
+ *
+ *  device    - the dfu device to commmunicate with
+ *
+ *  returns 0 on success, 1 if device was reset, error otherwise
+ */
 
 static int32_t dfu_transfer_out( dfu_device_t *device,
                                  uint8_t request,
@@ -93,30 +109,15 @@ static int32_t dfu_transfer_in( dfu_device_t *device,
                                 const size_t length );
 
 static void dfu_msg_response_output( const char *function, const int32_t result );
-
-/* Allocate an N-byte block of memory from the heap.
- *    If N is zero, allocate a 1-byte block.  */
-void* rpl_malloc( size_t n )
-{
-    if( 0 == n ) {
-        n = 1;
-    }
-
-    return malloc( n );
-}
-
-
-/*
- *  DFU_DETACH Request (DFU Spec 1.0, Section 5.1)
+/*  Used to output the response from our USB request in a human reable
+ *  form.
  *
- *  device    - the dfu device to commmunicate with
- *  timeout   - the timeout in ms the USB device should wait for a pending
- *              USB reset before giving up and terminating the operation
- *
- *  returns 0 or < 0 on error
+ *  function - the calling function to output on behalf of
+ *  result   - the result to interpret
  */
-int32_t dfu_detach( dfu_device_t *device, const int32_t timeout )
-{
+
+// ________  F U N C T I O N S  _______________________________
+int32_t dfu_detach( dfu_device_t *device, const int32_t timeout ) {
     int32_t result;
 
     TRACE( "%s( %p, %d )\n", __FUNCTION__, device, timeout );
@@ -133,19 +134,9 @@ int32_t dfu_detach( dfu_device_t *device, const int32_t timeout )
     return result;
 }
 
-
-/*
- *  DFU_DNLOAD Request (DFU Spec 1.0, Section 6.1.1)
- *
- *  device    - the dfu device to commmunicate with
- *  length    - the total number of bytes to transfer to the USB
- *              device - must be less than wTransferSize
- *  data      - the data to transfer
- *
- *  returns the number of bytes written or < 0 on error
- */
-int32_t dfu_download( dfu_device_t *device, const size_t length, uint8_t* data )
-{
+int32_t dfu_download( dfu_device_t *device,
+                      const size_t length,
+                      uint8_t* data ) {
     int32_t result;
 
     TRACE( "%s( %p, %u, %p )\n", __FUNCTION__, device, length, data );
@@ -166,7 +157,6 @@ int32_t dfu_download( dfu_device_t *device, const size_t length, uint8_t* data )
         return -3;
     }
 
-
     {
         size_t i;
         for( i = 0; i < length; i++ ) {
@@ -179,21 +169,12 @@ int32_t dfu_download( dfu_device_t *device, const size_t length, uint8_t* data )
     dfu_msg_response_output( __FUNCTION__, result );
 
     return result;
+// TODO : consider adding dfu_get_status here and returning status instead of
+// the length of the download? if there is a length mismatch on the download it
+// can be returned as -1.. this should simplify all calls to dfu_ from atmel_
 }
 
-
-/*
- *  DFU_UPLOAD Request (DFU Spec 1.0, Section 6.2)
- *
- *  device    - the dfu device to commmunicate with
- *  length    - the maximum number of bytes to receive from the USB
- *              device - must be less than wTransferSize
- *  data      - the buffer to put the received data in
- *
- *  returns the number of bytes received or < 0 on error
- */
-int32_t dfu_upload( dfu_device_t *device, const size_t length, uint8_t* data )
-{
+int32_t dfu_upload( dfu_device_t *device, const size_t length, uint8_t* data ) {
     int32_t result;
 
     TRACE( "%s( %p, %u, %p )\n", __FUNCTION__, device, length, data );
@@ -216,17 +197,7 @@ int32_t dfu_upload( dfu_device_t *device, const size_t length, uint8_t* data )
     return result;
 }
 
-
-/*
- *  DFU_GETSTATUS Request (DFU Spec 1.0, Section 6.1.2)
- *
- *  device    - the dfu device to commmunicate with
- *  status    - the data structure to be populated with the results
- *
- *  return the 0 if successful or < 0 on an error
- */
-int32_t dfu_get_status( dfu_device_t *device, dfu_status_t *status )
-{
+int32_t dfu_get_status( dfu_device_t *device, dfu_status_t *status ) {
     uint8_t buffer[6];
     int32_t result;
 
@@ -259,7 +230,7 @@ int32_t dfu_get_status( dfu_device_t *device, dfu_status_t *status )
         DEBUG( "==============================\n" );
         DEBUG( "status->bStatus: %s (0x%02x)\n",
                dfu_status_to_string(status->bStatus), status->bStatus );
-        DEBUG( "status->bwPollTimeout: 0x%04x\n", status->bwPollTimeout );
+        DEBUG( "status->bwPollTimeout: 0x%04x ms\n", status->bwPollTimeout );
         DEBUG( "status->bState: %s (0x%02x)\n",
                dfu_state_to_string(status->bState), status->bState );
         DEBUG( "status->iString: 0x%02x\n", status->iString );
@@ -275,16 +246,7 @@ int32_t dfu_get_status( dfu_device_t *device, dfu_status_t *status )
     return 0;
 }
 
-
-/*
- *  DFU_CLRSTATUS Request (DFU Spec 1.0, Section 6.1.3)
- *
- *  device    - the dfu device to commmunicate with
- *
- *  return 0 or < 0 on an error
- */
-int32_t dfu_clear_status( dfu_device_t *device )
-{
+int32_t dfu_clear_status( dfu_device_t *device ) {
     int32_t result;
 
     TRACE( "%s( %p )\n", __FUNCTION__, device );
@@ -301,16 +263,7 @@ int32_t dfu_clear_status( dfu_device_t *device )
     return result;
 }
 
-
-/*
- *  DFU_GETSTATE Request (DFU Spec 1.0, Section 6.1.5)
- *
- *  device    - the dfu device to commmunicate with
- *
- *  returns the state or < 0 on error
- */
-int32_t dfu_get_state( dfu_device_t *device )
-{
+int32_t dfu_get_state( dfu_device_t *device ) {
     int32_t result;
     uint8_t buffer[1];
 
@@ -334,16 +287,7 @@ int32_t dfu_get_state( dfu_device_t *device )
     return buffer[0];
 }
 
-
-/*
- *  DFU_ABORT Request (DFU Spec 1.0, Section 6.1.4)
- *
- *  device    - the dfu device to commmunicate with
- *
- *  returns 0 or < 0 on an error
- */
-int32_t dfu_abort( dfu_device_t *device )
-{
+int32_t dfu_abort( dfu_device_t *device ) {
     int32_t result;
 
     TRACE( "%s( %p )\n", __FUNCTION__, device );
@@ -360,17 +304,6 @@ int32_t dfu_abort( dfu_device_t *device )
     return result;
 }
 
-
-/*
- *  dfu_device_init is designed to find one of the usb devices which match
- *  the vendor and product parameters passed in.
- *
- *  vendor  - the vender number of the device to look for
- *  product - the product number of the device to look for
- *  [out] device - the dfu device to commmunicate with
- *
- *  return a pointer to the usb_device if found, or NULL otherwise
- */
 #ifdef HAVE_LIBUSB_1_0
 struct libusb_device *dfu_device_init( const uint32_t vendor,
                                        const uint32_t product,
@@ -378,8 +311,7 @@ struct libusb_device *dfu_device_init( const uint32_t vendor,
                                        const uint32_t device_address,
                                        dfu_device_t *dfu_device,
                                        const dfu_bool initial_abort,
-                                       const dfu_bool honor_interfaceclass )
-{
+                                       const dfu_bool honor_interfaceclass ) {
     libusb_device **list;
     size_t i,devicecount;
     extern libusb_context *usbcontext;
@@ -472,8 +404,7 @@ struct usb_device *dfu_device_init( const uint32_t vendor,
                                     const uint32_t device_address,
                                     dfu_device_t *dfu_device,
                                     const dfu_bool initial_abort,
-                                    const dfu_bool honor_interfaceclass )
-{
+                                    const dfu_bool honor_interfaceclass ) {
     struct usb_bus *usb_bus;
     struct usb_device *device;
     int32_t retries = 4;
@@ -483,7 +414,6 @@ struct usb_device *dfu_device_init( const uint32_t vendor,
            ((true == honor_interfaceclass) ? "true" : "false") );
 
 retry:
-
     if( 0 < retries ) {
         usb_find_busses();
         usb_find_devices();
@@ -550,16 +480,7 @@ retry:
 }
 #endif
 
-
-/*
- *  Used to convert the DFU state to a string.
- *
- *  state - the state to convert
- *
- *  returns the state name or "unknown state"
- */
-char* dfu_state_to_string( const int32_t state )
-{
+char* dfu_state_to_string( const int32_t state ) {
     char *message = "unknown state";
 
     switch( state ) {
@@ -601,16 +522,7 @@ char* dfu_state_to_string( const int32_t state )
     return message;
 }
 
-
-/*
- *  Used to convert the DFU status to a string.
- *
- *  status - the status to convert
- *
- *  returns the status name or "unknown status"
- */
-char* dfu_status_to_string( const int32_t status )
-{
+char* dfu_status_to_string( const int32_t status ) {
     char *message = "unknown status";
 
     switch( status ) {
@@ -662,27 +574,14 @@ char* dfu_status_to_string( const int32_t status )
         case DFU_STATUS_ERROR_STALLEDPKT:
             message = "errSTALLEDPKT";
             break;
-
     }
-
     return message;
 }
 
-
-/*
- *  Used to find the dfu interface for a device if there is one.
- *
- *  device - the device to search
- *  honor_interfaceclass - if the actual interface class information
- *                         should be checked, or ignored (bug in device DFU code)
- *
- *  returns the interface number if found, < 0 otherwise
- */
 #ifdef HAVE_LIBUSB_1_0
 static int32_t dfu_find_interface( struct libusb_device *device,
                                    const dfu_bool honor_interfaceclass,
-                                   const uint8_t bNumConfigurations)
-{
+                                   const uint8_t bNumConfigurations) {
     int32_t c,i,s;
 
     TRACE( "%s()\n", __FUNCTION__ );
@@ -737,8 +636,7 @@ static int32_t dfu_find_interface( struct libusb_device *device,
 }
 #else
 static int32_t dfu_find_interface( const struct usb_device *device,
-                                   const dfu_bool honor_interfaceclass )
-{
+                                   const dfu_bool honor_interfaceclass ) {
     int32_t c, i;
     struct usb_config_descriptor *config;
     struct usb_interface_descriptor *interface;
@@ -772,16 +670,8 @@ static int32_t dfu_find_interface( const struct usb_device *device,
 }
 #endif
 
-/*
- *  Gets the device into the dfuIDLE state if possible.
- *
- *  device    - the dfu device to commmunicate with
- *
- *  returns 0 on success, 1 if device was reset, error otherwise
- */
 static int32_t dfu_make_idle( dfu_device_t *device,
-                              const dfu_bool initial_abort )
-{
+                              const dfu_bool initial_abort ) {
     dfu_status_t status;
     int32_t retries = 4;
 
@@ -842,13 +732,11 @@ static int32_t dfu_make_idle( dfu_device_t *device,
     return -2;
 }
 
-
 static int32_t dfu_transfer_out( dfu_device_t *device,
                                  uint8_t request,
                                  const int32_t value,
                                  uint8_t* data,
-                                 const size_t length )
-{
+                                 const size_t length ) {
 #ifdef HAVE_LIBUSB_1_0
     return libusb_control_transfer( device->handle,
                 /* bmRequestType */ LIBUSB_ENDPOINT_OUT | LIBUSB_REQUEST_TYPE_CLASS | LIBUSB_RECIPIENT_INTERFACE,
@@ -874,8 +762,7 @@ static int32_t dfu_transfer_in( dfu_device_t *device,
                                 uint8_t request,
                                 const int32_t value,
                                 uint8_t* data,
-                                const size_t length )
-{
+                                const size_t length ) {
 #ifdef HAVE_LIBUSB_1_0
     return libusb_control_transfer( device->handle,
                 /* bmRequestType */ LIBUSB_ENDPOINT_IN | LIBUSB_REQUEST_TYPE_CLASS | LIBUSB_RECIPIENT_INTERFACE,
@@ -897,16 +784,8 @@ static int32_t dfu_transfer_in( dfu_device_t *device,
 #endif
 }
 
-
-/*
- *  Used to output the response from our USB request in a human reable
- *  form.
- *
- *  function - the calling function to output on behalf of
- *  result   - the result to interpret
- */
-static void dfu_msg_response_output( const char *function, const int32_t result )
-{
+static void dfu_msg_response_output( const char *function,
+                                     const int32_t result ) {
     char *msg = NULL;
 
     if( 0 <= result ) {
@@ -931,6 +810,7 @@ static void dfu_msg_response_output( const char *function, const int32_t result
                 msg = "-EILSEQ: CRC mismatch";
                 break;
             case -EPIPE:
+                // think that in libusb, -9 is LIBUSB_ERROR_PIPE
                 msg = "-EPIPE: a) Babble detect or b) Endpoint stalled";
                 break;
 #ifdef ETIMEDOUT
@@ -964,3 +844,14 @@ static void dfu_msg_response_output( const char *function, const int32_t result
         DEBUG( "%s 0x%08x (%d)\n", msg, result, result );
     }
 }
+
+#ifdef malloc
+#undef malloc
+void* rpl_malloc( size_t n ) {
+    if( 0 == n ) {
+        n = 1;
+    }
+
+    return malloc( n );
+}
+#endif
